==> 1.0.0.tar.gz: lib/atompaynetznonaes.dart <==
library atompaynetznonaes;
import 'package:crypto/crypto.dart';
import 'dart:convert';

class AtomPaynetzNonAes {
  final String login;
  final String pass;
  final String ttype = "NBFundTransfer";
  final String prodid;
  final String amt;
  final String username;
  final String mobile;
  final String email;
  final String address;
  final String txnid;
  final String txncurr = "INR";
  final String txnscamt = "0";
  final String clientcode;
  final String date;
  final String custacc;
  final String responsehashKey;
  final String requesthashKey;
  final String mode;
  final String mmp_txn;
  final String mer_txn;
  final String f_code;
  final String prod;
  final String discriminator;
  final String bank_txn;
  final String udf9;

  AtomPaynetzNonAes({
    this.login,
    this.pass,
    this.prodid,
    this.username,
    this.amt,
    this.mobile,
    this.address,
    this.email,
    this.date,
    this.txnid,
    this.custacc,
    this.requesthashKey,
    this.responsehashKey,
    this.clientcode,
    this.mode,
    this.mmp_txn,
    this.mer_txn,
    this.f_code,
    this.prod,
    this.discriminator,
    this.bank_txn,
    this.udf9,
  });

  getUrl() {
    var signature = this.createSignature();
    var bytes = utf8.encode(this.clientcode);
    var clientcodeEncoded = base64.encode(bytes);
    var url = "";
    if (this.mode == "live") {
      url = "https://payment.atomtech.in/paynetz/epi/fts?login=" +
          this.login +
          "&pass=" +
          this.pass +
          "&ttype=" +
          this.ttype +
          "&prodid=" +
          this.prodid +
          "&amt=" +
          this.amt +
          "&txncurr=" +
          this.txncurr +
          "&txnscamt=" +
          this.txnscamt +
          "&clientcode=" +
          clientcodeEncoded +
          "=&txnid=" +
          this.txnid +
          "&date=" +
          this.date +
          "&custacc=" +
          this.custacc +
          "&udf1=" +
          this.username +
          "&udf2=" +
          this.email +
          "&udf3=" +
          this.mobile +
          "&udf4=" +
          this.address +
          "&udf9=" +
          this.udf9 +
          "&ru=https://payment.atomtech.in/mobilesdk/param&signature=" +
          signature;
    } else {
      url = "https://paynetzuat.atomtech.in/paynetz/epi/fts?login=" +
          this.login +
          "&pass=" +
          this.pass +
          "&ttype=" +
          this.ttype +
          "&prodid=" +
          this.prodid +
          "&amt=" +
          this.amt +
          "&txncurr=" +
          this.txncurr +
          "&txnscamt=" +
          this.txnscamt +
          "&clientcode=" +
          clientcodeEncoded +
          "=&txnid=" +
          this.txnid +
          "&date=" +
          this.date +
          "&custacc=" +
          this.custacc +
          "&udf1=" +
          this.username +
          "&udf2=" +
          this.email +
          "&udf3=" +
          this.mobile +
          "&udf4=" +
          this.address +
          "&udf9=" +
          this.udf9 +
          "&ru=https://pgtest.atomtech.in/mobilesdk/param&signature=" +
          signature;
    }
    return (url);
  }

  createSignature() {
    String signatureString = this.login +
        this.pass +
        this.ttype +
        this.prodid +
        this.txnid +
        this.amt +
        this.txncurr;
    var bytes = utf8.encode(signatureString);
    var key = utf8.encode(this.requesthashKey);
    var hmacSha512 = new Hmac(sha512, key); // HMAC-SHA256
    var digest = hmacSha512.convert(bytes);
    return (digest.toString());
  }

  validateSignature(Map data, resHashKey) {
    var f_code = '';
    if (data['f_code'] == 'success_00' || data['f_code'] == 'Ok') {
      f_code = 'Ok';
    } else if (data['f_code'] == 'C_06' || data['f_code'] == 'C') {
      f_code = 'C';
    } else {
      f_code = 'F';
    }
    String signatureString = data['mmp_txn'] +
        data['mer_txn'] +
        f_code +
        data['prod'] +
        data['discriminator'] +
        data['amt'] +
        data['bank_txn'];
    var bytes = utf8.encode(signatureString);
    var key = utf8.encode(resHashKey);
    var hmacSha512 = new Hmac(sha512, key); // HMAC-SHA256
    var digest = hmacSha512.convert(bytes);
    var genSig = digest.toString();
    if (data['signature'] == genSig) {
      return true;
    } else {
      return false;
    }
  }
}

==> 1.0.3.tar.gz: lib/atompaynetznonaes.dart <==
library atompaynetznonaes;

import 'package:crypto/crypto.dart';
import 'dart:convert';

class AtomPaynetzNonAes {
  final String login;
  final String pass;
  final String ttype = "NBFundTransfer";
  final String prodid;
  final String amt;
  final String username;
  final String mobile;
  final String email;
  final String address;
  final String txnid;
  final String txncurr = "INR";
  final String txnscamt = "0";
  final String clientcode;
  final String date;
  final String custacc;
  final String responsehashKey;
  final String requesthashKey;
  final String mode;
  final String udf9;

  AtomPaynetzNonAes({
    required this.login,
    required this.pass,
    required this.prodid,
    required this.username,
    required this.amt,
    required this.mobile,
    required this.address,
    required this.email,
    required this.date,
    required this.txnid,
    required this.custacc,
    required this.requesthashKey,
    required this.responsehashKey,
    required this.clientcode,
    required this.mode,
    required this.udf9,
  });

  getUrl() {
    var signature = this.createSignature();
    var bytes = utf8.encode(this.clientcode);
    var clientcodeEncoded = base64.encode(bytes);
    var url = "";
    if (this.mode == "live") {
      url = "https://payment.atomtech.in/paynetz/epi/fts?login=" +
          this.login +
          "&pass=" +
          this.pass +
          "&ttype=" +
          this.ttype +
          "&prodid=" +
          this.prodid +
          "&amt=" +
          this.amt +
          "&txncurr=" +
          this.txncurr +
          "&txnscamt=" +
          this.txnscamt +
          "&clientcode=" +
          clientcodeEncoded +
          "=&txnid=" +
          this.txnid +
          "&date=" +
          this.date +
          "&custacc=" +
          this.custacc +
          "&udf1=" +
          this.username +
          "&udf2=" +
          this.email +
          "&udf3=" +
          this.mobile +
          "&udf4=" +
          this.address +
          "&udf9=" +
          this.udf9 +
          "&ru=https://payment.atomtech.in/mobilesdk/param&signature=" +
          signature;
    } else {
      url = "https://paynetzuat.atomtech.in/paynetz/epi/fts?login=" +
          this.login +
          "&pass=" +
          this.pass +
          "&ttype=" +
          this.ttype +
          "&prodid=" +
          this.prodid +
          "&amt=" +
          this.amt +
          "&txncurr=" +
          this.txncurr +
          "&txnscamt=" +
          this.txnscamt +
          "&clientcode=" +
          clientcodeEncoded +
          "=&txnid=" +
          this.txnid +
          "&date=" +
          this.date +
          "&custacc=" +
          this.custacc +
          "&udf1=" +
          this.username +
          "&udf2=" +
          this.email +
          "&udf3=" +
          this.mobile +
          "&udf4=" +
          this.address +
          "&udf9=" +
          this.udf9 +
          "&ru=https://pgtest.atomtech.in/mobilesdk/param&signature=" +
          signature;
    }
    return (url);
  }

  createSignature() {
    String signatureString = this.login +
        this.pass +
        this.ttype +
        this.prodid +
        this.txnid +
        this.amt +
        this.txncurr;
    var bytes = utf8.encode(signatureString);
    var key = utf8.encode(this.requesthashKey);
    var hmacSha512 = new Hmac(sha512, key); // HMAC-SHA256
    var digest = hmacSha512.convert(bytes);
    return (digest.toString());
  }
}

class VerifyTransaction {
  validateSignature(Map data, resHashKey) {
    var f_code = '';
    if (data['f_code'] == 'success_00' || data['f_code'] == 'Ok') {
      f_code = 'Ok';
    } else if (data['f_code'] == 'C_06' || data['f_code'] == 'C') {
      f_code = 'C';
    } else {
      f_code = 'F';
    }
    String signatureString = data['mmp_txn'] +
        data['mer_txn'] +
        f_code +
        data['prod'] +
        data['discriminator'] +
        data['amt'] +
        data['bank_txn'];
    var bytes = utf8.encode(signatureString);
    var key = utf8.encode(resHashKey);
    var hmacSha512 = new Hmac(sha512, key); // HMAC-SHA256
    var digest = hmacSha512.convert(bytes);
    var genSig = digest.toString();
    if (data['signature'] == genSig) {
      return true;
    } else {
      return false;
    }
  }
}
